| Title: | Mixed effects Score Test for continuous outcomes |
|---|---|
| Description: | Test for association between a set of SNPS/genes and continuous or binary outcomes by including variant characteristic information and using (weighted) score statistics. |
| Authors: | Jianping Sun [aut], Yingye Zheng [aut], Li Hsu [aut], Mickaël Canouil [cre, ctb] (ORCID: <https://orcid.org/0000-0002-3396-4549>), Mathilde Boissel [ctb] (ORCID: <https://orcid.org/0000-0001-5719-8749>) |
| Maintainer: | Mickaël Canouil <[email protected]> |
| License: | LGPL (>= 2.1) |
| Version: | 1.0.4 |
| Built: | 2026-05-17 06:17:11 UTC |
| Source: | https://github.com/mcanouil/MiSTr |
Test for association between a set of SNPS/genes and continuous outcomes by including variant characteristic information and using score statistics.
mist( y, X, G, Z, method = "liu", model = c("guess", "continuous", "binary"), weight.beta = NULL, maf = NULL )mist( y, X, G, Z, method = "liu", model = c("guess", "continuous", "binary"), weight.beta = NULL, maf = NULL )
y |
[numeric] A |
X |
[numeric] A |
G |
[numeric] A |
Z |
[numeric] a |
method |
[character] A method to compute the p-value and the default value is "liu". Method "davies" represents an exact method that computes the p-value by inverting the characteristic function of the mixture chisq. Method "liu" represents an approximation method that matches the first 3 moments. |
model |
[character] A |
weight.beta |
[numeric] A |
maf |
[numeric] A |
S.tau score Statistic for the variant heterogeneous effect.
S.pi score Statistic for the variant mean effect.
p.value.S.tau P-value for testing the variant heterogeneous effect.
p.value.S.pi P-value for testing the variant mean effect.
p.value.overall Overall p-value for testing the association between the set of SNPS/genes and outcomes. It combines p.value.S.pi and p.value.S.tau by using Fisher's procedure.
library(MiSTr) data(mist_data) attach(mist_data) mist( y = phenotypes[, "y_taupi"], X = phenotypes[, paste0("x_cov", 0:2)], G = genotypes, Z = variants_info[, 1, drop = FALSE] ) mist( y = phenotypes[, "y_binary"], X = phenotypes[, paste0("x_cov", 0:2)], G = genotypes, Z = variants_info[, 1, drop = FALSE] )library(MiSTr) data(mist_data) attach(mist_data) mist( y = phenotypes[, "y_taupi"], X = phenotypes[, paste0("x_cov", 0:2)], G = genotypes, Z = variants_info[, 1, drop = FALSE] ) mist( y = phenotypes[, "y_binary"], X = phenotypes[, paste0("x_cov", 0:2)], G = genotypes, Z = variants_info[, 1, drop = FALSE] )
Print method for mist objec
## S3 method for class 'mist' print(x, ...)## S3 method for class 'mist' print(x, ...)
x |
[mist] |
... |
Other arguments (Not used). |
list